@@ -36,7 +36,7 @@ def buildAdvancedPriceFeatures(quotes_df=None, lookback_window=20, rolling_direc
 
 
 class AbstractAssembler(ABC):
-    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
+    def __init__(self, starting_date = None, running_date=None, drop_token=None, dropbox_backup=True, returns_pkl_file_name='returns.pkl', features_pkl_file_name='features.pkl', ts_features_pkl_file_name='tsfresh_features.pkl', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy',shortcut_features_saving_suffix='_shortcut_features.npy', shortcut_features_names_saving_suffix='shortcut_features_names.npy',shortcut_features_pkl_file_name = 'shortcut.pkl', local_root_directory='../data/', user='napoleon',macro_features_directory = 'features_macro', rolling_direction=1):
         super().__init__()
         self.local_root_directory = local_root_directory
         self.user = user
@@ -51,6 +51,8 @@ class AbstractAssembler(ABC):
         self.starting_date=starting_date
         self.rolling_direction = rolling_direction
         self.ts_features_pkl_file_name=ts_features_pkl_file_name
+        self.shortcut_features_saving_suffix = shortcut_features_saving_suffix
+        self.shortcut_features_names_saving_suffix = shortcut_features_names_saving_suffix
 
     @abstractmethod
     def assembleFeature(self, feature_type, n_past_features, tsfresh_lookback_window):
@@ -461,7 +463,7 @@ class FeaturesAssembler(AbstractAssembler):
         print('Actual max shortcut feature date '+str(max(shortcut_features_df['Date'])))
 
         shortcut_features_df = shortcut_features_df[shortcut_features_df['Date'] >= self.starting_date]
-        shortcut_features_df = shortcut_features_df[shortcut_features_df['Date'] <= self.ending_date]
+        shortcut_features_df = shortcut_features_df[shortcut_features_df['Date'] <= self.running_date]
         print('Max shortcut date '+str(max(shortcut_features_df['Date'])))
         print('Min shortcut date '+str(min(shortcut_features_df['Date'])))
 
@@ -587,6 +589,6 @@ class FeaturesAssembler(AbstractAssembler):
         if np.isinf(features).sum(axis=0).sum() > 0:
             raise Exception('inf values for assembled features')
         print('final size saved '+str(features.shape))
-        self.dbx.local_features_npy_save_and_upload(starting_date = self.starting_date,ending_date = self.running_date, shortcut_features=shortcut_features, features = features,features_names= predictor_names,feature_type=feature_type, n_past_features = n_past_features , local_root_directory= self.local_root_directory, user = self.user, features_saving_suffix=self.features_saving_suffix, features_names_saving_suffix=self.features_names_saving_suffix)
+        self.dbx.local_features_npy_save_and_upload(starting_date = self.starting_date,ending_date = self.running_date, shortcut_features=shortcut_features, features = features,features_names= predictor_names, shortcut_features_names = shortcut_features_names, feature_type=feature_type, n_past_features = n_past_features , local_root_directory= self.local_root_directory, user = self.user, features_saving_suffix=self.features_saving_suffix, features_names_saving_suffix=self.features_names_saving_suffix, shortcut_features_saving_suffix=self.shortcut_features_saving_suffix, shortcut_features_names_saving_suffix=self.shortcut_features_names_saving_suffix)
 
 
