@@ -112,7 +112,7 @@ class SimpleRunner(AbstractRunner):
                                                     local_root_directory=self.local_root_directory, user=self.user,
                                                     features_saving_suffix=self.features_saving_suffix,
                                                     features_names_saving_suffix=self.features_names_saving_suffix,
-                                                    shortcut_features_pkl_file_name=self.shortcut_features_pkl_file_name)
+                                                    shortcut_features_saving_suffix=self.shortcut_features_saving_suffix)
 
 
         # the save files necessarily match the beginning date
